import random, string
import numpy as np
import h5py

def random_string(n=10):
    return ''.join(random.SystemRandom().choice(string.digits + string.ascii_uppercase) 
                   for _ in range(n))

fn = "test-ascii-length-bug.h5"


test = h5py.File(fn, "w")
standard_ascii = "mar231-21y ha131d a litt321le lamb its Fleece As Wh31ite as snow".split()
random_strings = [random_string() for _ in range(20)]
codedb = np.array(standard_ascii, dtype="a10")
test.create_dataset("/test/ascii", data=codedb)
codedc = np.array(random_strings, dtype="a11")
test.create_dataset("/test/randomalpha", data=codedc)
codedd = np.array(random_strings, dtype="a10")
test.create_dataset("/test/randomalphashort", data=codedd)
test.close()



import h5py
from numpy import array
import os

os.chdir('/Users/mario/CloudStation/Programming/workspace_h5/_pkg_h5/inst')

with h5py.File('test-h5link.h5', 'w') as f:
    grp = f.create_group("testgroup")
    grp["test"] = array([1, 2, 3])
    subgrp = grp.create_group("subgroup")
    subgrp["test-sub"] = array([4, 5, 6])
    
    # Create Hardlink
    grp2 = f.create_group("hardlink")
    grp2["test2"] = grp["test"]
    
    # Create Softlink
    grp3 = f.create_group("softlink")
    grp3["test3"] = h5py.SoftLink('/testgroup')
    
    # Create External link
    grp4 = f.create_group("extlink")
    grp4["test4"] = h5py.ExternalLink("test-f32.h5", "/")
